==> haskell-hspec-wai-0.9.0-80-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai
version: 0.9.0
id: hspec-wai-0.9.0-HxQ7CkYzr4lVq6reAQhpE
key: hspec-wai-0.9.0-HxQ7CkYzr4lVq6reAQhpE
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2015 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Experimental Hspec support for testing WAI applications
description:
    Experimental Hspec support for testing WAI applications
category: Testing
abi: 8356cc8ca261faa0f749a150777d5f5d
exposed: True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck
hidden-modules: Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-wai-0.9.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-wai-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-wai-0.9.0
hs-libraries: HShspec-wai-0.9.0-HxQ7CkYzr4lVq6reAQhpE
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    hspec-core-2.5.2-9yo5sXi9naN78n6zxAG5x3
    hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
    http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq text-1.2.3.0
    transformers-0.5.5.0 wai-3.2.1.2-2H9p9HQiwTJLLqNxJrJ7sw
    wai-extra-3.0.22.1-E2Ld0a9Zx9yJ42ojKTsQIg
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             hspec-core-2.5.2-9yo5sXi9naN78n6zxAG5x3=b1c4150b7af77d22c2c1e81c0ac77914
             hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk=0f0d928add941ac9e4a9f5dba9348ac8
             http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq=681a4d4f5ae8e517c4372dabe00b35c0
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             wai-3.2.1.2-2H9p9HQiwTJLLqNxJrJ7sw=4dcfd1f19878874b7a3f1edbd12d60e9
             wai-extra-3.0.22.1-E2Ld0a9Zx9yJ42ojKTsQIg=b409700ed4183de54f1903c8a52af997
haddock-interfaces: /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-0.9.0-83-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai
version: 0.9.0
id: hspec-wai-0.9.0-88Tmwq3Dijf6BsLaNcrND2
key: hspec-wai-0.9.0-88Tmwq3Dijf6BsLaNcrND2
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2015 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Experimental Hspec support for testing WAI applications
description:
    Experimental Hspec support for testing WAI applications
category: Testing
abi: 5a1d43961b5aadf0f57a0d8046b5a0e9
exposed: True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck
hidden-modules: Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-wai-0.9.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-wai-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-wai-0.9.0
hs-libraries: HShspec-wai-0.9.0-88Tmwq3Dijf6BsLaNcrND2
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    hspec-core-2.5.3-Ams2XuOnNDi8kkLterMX9N
    hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
    http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc text-1.2.3.0
    transformers-0.5.5.0 wai-3.2.1.2-FYNUSCGVi1MEtdQVVwNIxx
    wai-extra-3.0.22.1-KJlyHFpeYikDUiMv1Gg7on
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             hspec-core-2.5.3-Ams2XuOnNDi8kkLterMX9N=e0a953b556df722532d5f3ec3bd0085a
             hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk=0f0d928add941ac9e4a9f5dba9348ac8
             http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc=48aca1d059bd297a17f6a458e8d85d56
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             wai-3.2.1.2-FYNUSCGVi1MEtdQVVwNIxx=a10b0b451ac20f27f6160db52b013dec
             wai-extra-3.0.22.1-KJlyHFpeYikDUiMv1Gg7on=a72ffbe2bfa51351bf53d691c5b04e1a
haddock-interfaces: /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
